@@ -1,12 +1,12 @@
 /*
  *  package.h
- * 
- *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
+ *
+ *  Copyright (c) 2002-2007 by Judd Vinet <jvinet@zeroflux.org>
  *  Copyright (c) 2005 by Aurelien Foret <orelien@chez.com>
  *  Copyright (c) 2006 by David Kimpe <dnaku@frugalware.org>
  *  Copyright (c) 2005, 2006 by Christian Hamar <krics@linuxforum.hu>
  *  Copyright (c) 2005, 2006 by Miklos Vajna <vmiklos@frugalware.org>
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -18,16 +18,12 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
- *  USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef _ALPM_PACKAGE_H
 #define _ALPM_PACKAGE_H
 
-#if defined(__APPLE__) || defined(__sun__)
 #include <time.h>
-#endif
 
 #include "alpm.h"
 #include "db.h"
@@ -48,7 +44,6 @@ typedef enum _pmpkgfrom_t {
 #define PKG_TYPE_LEN     32
 #define PKG_PACKAGER_LEN 64
 #define PKG_MD5SUM_LEN   33
-#define PKG_SHA1SUM_LEN  41
 #define PKG_ARCH_LEN     32
 
 struct __pmpkg_t {
@@ -57,57 +52,48 @@ struct __pmpkg_t {
 	char version[PKG_VERSION_LEN];
 	char desc[PKG_DESC_LEN];
 	char url[PKG_URL_LEN];
-	char builddate[PKG_DATE_LEN];
-	char buildtype[PKG_TYPE_LEN];
-	char installdate[PKG_DATE_LEN];
+	time_t builddate;
+	time_t installdate;
 	char packager[PKG_PACKAGER_LEN];
 	char md5sum[PKG_MD5SUM_LEN];
-	char sha1sum[PKG_SHA1SUM_LEN];
 	char arch[PKG_ARCH_LEN];
 	unsigned long size;
 	unsigned long isize;
 	unsigned short scriptlet;
 	unsigned short force;
-	time_t date;
 	pmpkgreason_t reason;
-	/* alpm_list_t *desc_localized;*/
 	alpm_list_t *licenses;
 	alpm_list_t *replaces;
 	alpm_list_t *groups;
 	alpm_list_t *files;
 	alpm_list_t *backup;
 	alpm_list_t *depends;
-	alpm_list_t *removes;
-	alpm_list_t *requiredby;
+	alpm_list_t *optdepends;
 	alpm_list_t *conflicts;
 	alpm_list_t *provides;
+	alpm_list_t *deltas;
 	/* internal */
 	pmpkgfrom_t origin;
-	void *data;
-	/* TODO replace 'data' with this:
+	/* Replaced 'void *data' with this union as follows:
   origin == PKG_FROM_CACHE, use pkg->origin_data.db
-  origin == PKG_FROM_FILE, use pkg->origin_data.fd
-  union {
-		int fd;
-		pmdb_t *db;
-	} origin_data;
+  origin == PKG_FROM_FILE, use pkg->origin_data.file
 	*/
+  union {
+		pmdb_t *db;
+		char *file;
+	} origin_data;
 	pmdbinfrq_t infolevel;
 };
 
-#define FREEPKG(p) do { if(p){_alpm_pkg_free(p); p = NULL;}} while(0)
-#define FREELISTPKGS(p) _FREELIST(p, _alpm_pkg_free)
-
+int _alpm_versioncmp(const char *a, const char *b);
 pmpkg_t* _alpm_pkg_new(const char *name, const char *version);
 pmpkg_t *_alpm_pkg_dup(pmpkg_t *pkg);
-void _alpm_pkg_free(void *data);
+void _alpm_pkg_free(pmpkg_t *pkg);
 int _alpm_pkg_cmp(const void *p1, const void *p2);
 int alpm_pkg_compare_versions(pmpkg_t *local_pkg, pmpkg_t *pkg);
-pmpkg_t *_alpm_pkg_load(const char *pkgfile);
+pmpkg_t *_alpm_pkg_load(const char *pkgfile, unsigned short full);
 pmpkg_t *_alpm_pkg_find(const char *needle, alpm_list_t *haystack);
-int _alpm_pkg_splitname(const char *target, char *name, char *version, int witharch);
-int _alpm_pkg_istoonew(pmpkg_t *pkg);
-void _alpm_pkg_update_requiredby(pmpkg_t *pkg);
+int _alpm_pkg_should_ignore(pmpkg_t *pkg);
 
 #endif /* _ALPM_PACKAGE_H */
 
