@@ -1,8 +1,8 @@
 /*
  *  server.h
- * 
+ *
  *  Copyright (c) 2006 by Miklos Vajna <vmiklos@frugalware.org>
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -14,9 +14,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
- *  USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef _ALPM_SERVER_H
 #define _ALPM_SERVER_H
@@ -27,8 +25,6 @@
 #include <time.h>
 #include <download.h>
 
-#define FREESERVER(p) do { if(p){_alpm_server_free(p); p = NULL;}} while(0)
-
 /* Servers */
 struct __pmserver_t {
 	/* useless abstraction now? */
@@ -38,12 +34,12 @@ struct __pmserver_t {
 #define PM_DLBUF_LEN (1024 * 10)
 
 pmserver_t *_alpm_server_new(const char *url);
-void _alpm_server_free(void *data);
-int _alpm_downloadfiles(alpm_list_t *servers, const char *localpath, alpm_list_t *files);
+void _alpm_server_free(pmserver_t *server);
+int _alpm_downloadfiles(alpm_list_t *servers, const char *localpath,
+		alpm_list_t *files, int *dl_total, unsigned long totalsize);
 int _alpm_downloadfiles_forreal(alpm_list_t *servers, const char *localpath,
-	alpm_list_t *files, const char *mtime1, char *mtime2);
-
-char *_alpm_fetch_pkgurl(char *target);
+	alpm_list_t *files, time_t mtime1, time_t *mtime2, int *dl_total,
+	unsigned long totalsize);
 
 #endif /* _ALPM_SERVER_H */
 
