@@ -1,11 +1,11 @@
 /*
  *  trans.h
- * 
- *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
+ *
+ *  Copyright (c) 2002-2007 by Judd Vinet <jvinet@zeroflux.org>
  *  Copyright (c) 2005 by Aurelien Foret <orelien@chez.com>
  *  Copyright (c) 2005 by Christian Hamar <krics@linuxforum.hu>
  *  Copyright (c) 2006 by Miklos Vajna <vmiklos@frugalware.org>
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -17,9 +17,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
- *  USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef _ALPM_TRANS_H
 #define _ALPM_TRANS_H
@@ -50,13 +48,6 @@ struct __pmtrans_t {
 	alpm_trans_cb_progress cb_progress;
 };
 
-#define FREETRANS(p) \
-do { \
-	if(p) { \
-		_alpm_trans_free(p); \
-		p = NULL; \
-	} \
-} while (0)
 #define EVENT(t, e, d1, d2) \
 do { \
 	if((t) && (t)->cb_event) { \
@@ -77,7 +68,7 @@ do { \
 } while(0)
 
 pmtrans_t *_alpm_trans_new(void);
-void _alpm_trans_free(void *data);
+void _alpm_trans_free(pmtrans_t *trans);
 int _alpm_trans_init(pmtrans_t *trans, pmtranstype_t type, pmtransflag_t flags,
                      alpm_trans_cb_event event, alpm_trans_cb_conv conv,
                      alpm_trans_cb_progress progress);
@@ -85,7 +76,9 @@ int _alpm_trans_sysupgrade(pmtrans_t *trans);
 int _alpm_trans_addtarget(pmtrans_t *trans, char *target);
 int _alpm_trans_prepare(pmtrans_t *trans, alpm_list_t **data);
 int _alpm_trans_commit(pmtrans_t *trans, alpm_list_t **data);
-int _alpm_trans_update_depends(pmtrans_t *trans, pmpkg_t *pkg);
+int _alpm_runscriptlet(const char *root, const char *installfn,
+                       const char *script, const char *ver,
+                       const char *oldver, pmtrans_t *trans);
 
 #endif /* _ALPM_TRANS_H */
 
