@@ -1,4 +1,4 @@
-self.description = "Try to upgrade packages which would break a multiple-depend"
+self.description = "Upgrade packages which would break a multiple-depend"
 
 lp1 = pmpkg("pkg1")
 lp1.depends = ["imaginary"]
